@@ -15,7 +15,13 @@ var urlCmd = &cobra.Command{
 		printing.Summary(options, args[0])
 		if len(args) >= 1 {
 			printing.DalLog("SYSTEM", "Using single target mode", options)
+			if options.Format == "json" {
+				printing.DalLog("PRINT", "[", options)
+			}
 			_, _ = scanning.Scan(args[0], options, "Single")
+			if options.Format == "json" {
+				printing.DalLog("PRINT", "{}]", options)
+			}
 		} else {
 			printing.DalLog("ERROR", "Input target url", options)
 			printing.DalLog("ERROR", "e.g dalfox url https://google.com/?q=1", options)
